# Examples

Here are a few examples of using the Topography data component,
*bmi-topography*.

* `topography.ipynb` and `bmi-topography.ipynb`: These Jupyter Notebooks show
  how to call the Topography data component through its API and its BMI,
  respectively.
* `bmi-topography_ex.sh`: This shell script demonstrates how to call the
  Topography CLI.
* `bmi-topography_ex.py`: An example Python script is used in the main
  [README](../README.md).
* `config.yaml`: A configuration file used to pass parameters to the Topography
  BMI.
